# examples.mk

ifeq (,$sources)
  $(error need sources)
endif 

ifeq (,$(findstring $(TARGET),dos linux win32))
  $(error need TARGET=dos | linux | win32)
endif

ifeq (,$(findstring $(GFX),fbgfx yagl mygl none))
  $(error need GFX=fbgfx | yagl | mygl)
endif

ifndef $(main)
  main := $(basename $(firstword $(sources)))
else
  main := $(basename $(main))
endif
ifdef exename
  ifneq ($(TARGET),linux)
    exename := $(addsuffix .exe,$(main))
  endif
else
ifeq ($(GFX),none)
  ifeq ($(TARGET),linux)
    exename := $(main)
  else
    exename := $(main).exe
  endif
else
  ifeq ($(TARGET),linux)
    exename := $(main)_$(GFX)
  else
    exename := $(main)_$(GFX).exe
  endif
endif
endif

ifndef objpath
  objpath=./obj/$(TARGET)
endif

ifndef FBC
  ifeq ($(TARGET),dos)
    FBC = fbc_dos.exe
  else
    ifeq ($(TARGET),win32)
      FBC = fbc.exe
    else
      FBC = fbc
    endif
  endif
endif

FBFLAGS := 
ifeq ($(DEBUG),1)
  FBFLAGS += -g
#  FBFLAGS += -w pedantic
endif

ifdef INCLUDEDIR
  FBFLAGS += -i $(INCLUDEDIR)
endif

ifdef LIBDIR
  FBFLAGS += -p $(LIBDIR)/$(TARGET)
endif

all : checkdirs $(exename) $(headers)

$(objpath)/$(exename) : $(sources) 
	$(FBC) $(sources) -m $(main) $(FBFLAGS) -x $(exename)

$(objpath) : 
	mkdir -p $(objpath)

.PHONY : checkdirs
checkdirs : $(objpath)

.PHONY : clean
clean :
	rm -f $(objects)
	rm -f $(exename)
